==> owncloud-8.2.2-2-any.pkg.tar.xz: usr/share/webapps/owncloud/apps/files_external/l10n/sl.js <==
OC.L10N.register(
    "files_external",
    {
    "Step 1 failed. Exception: %s" : "1. korak je spodletel. Izjemna napaka: %s",
    "Step 2 failed. Exception: %s" : "2. korak je spodletel. Izjemna napaka: %s",
    "External storage" : "Zunanja shramba",
    "Storage with id \"%i\" not found" : "Shrambe z ID \"%i\" ni mogoče najti.",
    "Invalid mount point" : "Neveljavna priklopna točka",
    "Invalid storage backend \"%s\"" : "Neveljaven ozadnji program shrambe \"%s\"",
    "Personal" : "Osebno",
    "System" : "Sistem",
    "Grant access" : "Odobri dostop",
    "Access granted" : "Dostop je odobren",
    "Generate keys" : "Ustvari ključe",
    "Error generating key pair" : "Prišlo je do napake med ustvarjanjem para ključev",
    "Enable encryption" : "Omogoči šifriranje",
    "Enable previews" : "Omogoči predogled",
    "Check for changes" : "Preveri za spremembe",
    "Never" : "Nikoli",
    "Once every direct access" : "Enkrat ob neposrednem dostopu",
    "Every time the filesystem is used" : "Kadarkoli je datotečni sistem v uporabi",
    "All users. Type to select user or group." : "Vsi uporabniki. Skupino ali uporabnika je mogoče tudi izbrati.",
    "(group)" : "(skupina)",
    "Saved" : "Shranjeno",
    "None" : "Brez",
    "App key" : "Programski ključ",
    "App secret" : "Skrivni programski ključ",
    "Client ID" : "ID odjemalca",
    "Client secret" : "Skrivni ključ odjemalca",
    "Username" : "Uporabniško ime",
    "Password" : "Geslo",
    "API key" : "Ključ API",
    "Public key" : "Javni ključ",
    "Amazon S3" : "Amazon S3",
    "Bucket" : "Pomnilniško vedro",
    "Hostname" : "Ime gostitelja",
    "Port" : "Vrata",
    "Region" : "Območje",
    "Enable SSL" : "Omogoči SSL",
    "Enable Path Style" : "Omogoči slog poti",
    "WebDAV" : "WebDAV",
    "URL" : "Naslov URL",
    "Remote subfolder" : "Oddaljena podrejena mapa",
    "Secure https://" : "Varni način https://",
    "Dropbox" : "Dropbox",
    "Host" : "Gostitelj",
    "Secure ftps://" : "Varni način ftps://",
    "Local" : "Krajevno",
    "Location" : "Mesto",
    "ownCloud" : "ownCloud",
    "Root" : "Koren",
    "SFTP with secret key login" : "Prijava preko protokola SFTP z geslom",
    "Share" : "Souporaba",
    "SMB / CIFS using OC login" : "SMB / CIFS z uporabo prijave OC",
    "Username as share" : "Uporabniško ime za souporabo",
    "OpenStack Object Storage" : "Shramba predmeta OpenStack",
    "<b>Note:</b> " : "<b>Opomba:</b> ",
    "<b>Note:</b> The cURL support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "<b>Opomba:</b> Podpora za naslove cURL v PHP ni omogočena, ali pa ni ustrezno nameščenih programov. Priklapljanje %s ni mogoče. Za pomoč pri namestitvi se obrnite na sistemskega skrbnika.",
    "<b>Note:</b> The FTP support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "<b>Opomba:</b> Podpora za protokol FTP v PHP ni omogočena, ali pa ni ustrezno nameščenih programov. Priklapljanje %s ni mogoče. Za pomoč pri namestitvi se obrnite na sistemskega skrbnika.",
    "<b>Note:</b> \"%s\" is not installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "<b>Opomba:</b> Program \"%s\" ni nameščen. Priklapljanje %s ni mogoče. Za pomoč pri namestitvi se obrnite na sistemskega skrbnika.",
    "No external storage configured" : "Ni določene zunanje shrambe",
    "You can add external storages in the personal settings" : "Med nastavitvami je mogoče dodati tudi zunanjo shrambo.",
    "Name" : "Ime",
    "Storage type" : "Vrsta shrambe",
    "Scope" : "Obseg",
    "External Storage" : "Zunanja podatkovna shramba",
    "Folder name" : "Ime mape",
    "Configuration" : "Nastavitve",
    "Available for" : "Na voljo za",
    "Advanced settings" : "Napredne nastavitve",
    "Delete" : "Izbriši",
    "Add storage" : "Dodaj shrambo",
    "Enable User External Storage" : "Omogoči zunanjo uporabniško podatkovno shrambo",
    "Allow users to mount the following external storage" : "Dovoli uporabnikom priklapljanje navedenih zunanjih shramb."
},
"nplurals=4; plural=(n%100==1 ? 0 : n%100==2 ? 1 : n%100==3 || n%100==4 ? 2 : 3);");

==> owncloud-9.0.0-1-any.pkg.tar.xz: usr/share/webapps/owncloud/apps/files_external/l10n/sl.js <==
OC.L10N.register(
    "files_external",
    {
    "Step 1 failed. Exception: %s" : "1. korak je spodletel. Izjemna napaka: %s",
    "Step 2 failed. Exception: %s" : "2. korak je spodletel. Izjemna napaka: %s",
    "External storage" : "Zunanja shramba",
    "Storage with id \"%i\" not found" : "Shrambe z ID \"%i\" ni mogoče najti.",
    "Invalid mount point" : "Neveljavna priklopna točka",
    "Invalid storage backend \"%s\"" : "Neveljaven ozadnji program shrambe \"%s\"",
    "Insufficient data: %s" : "Nepopolni podatki: %s",
    "%s" : "%s",
    "Personal" : "Osebno",
    "System" : "Sistem",
    "Grant access" : "Odobri dostop",
    "Access granted" : "Dostop je odobren",
    "Error configuring OAuth1" : "Napaka nastavljanja OAuth1",
    "Error configuring OAuth2" : "Napaka nastavljanja OAuth2",
    "Generate keys" : "Ustvari ključe",
    "Error generating key pair" : "Prišlo je do napake med ustvarjanjem para ključev",
    "Enable encryption" : "Omogoči šifriranje",
    "Enable previews" : "Omogoči predogled",
    "Check for changes" : "Preveri za spremembe",
    "Never" : "Nikoli",
    "Once every direct access" : "Enkrat ob neposrednem dostopu",
    "All users. Type to select user or group." : "Vsi uporabniki. Skupino ali uporabnika je mogoče tudi izbrati.",
    "(group)" : "(skupina)",
    "Saved" : "Shranjeno",
    "External mount error" : "Notranja napaka priklopa",
    "Username" : "Uporabniško ime",
    "Password" : "Geslo",
    "Save" : "Shrani",
    "Access key" : "Ključ za dostop",
    "Secret key" : "Skriti ključ",
    "Builtin" : "Vgrajeno",
    "None" : "Brez",
    "OAuth1" : "OAuth1",
    "App key" : "Programski ključ",
    "App secret" : "Skrivni programski ključ",
    "OAuth2" : "OAuth2",
    "Client ID" : "ID odjemalca",
    "Client secret" : "Skrivni ključ odjemalca",
    "OpenStack" : "OpenStack",
    "Tenant name" : "Ime uporabnika",
    "API key" : "Ključ API",
    "Username and password" : "Uporabniško ime in geslo",
    "RSA public key" : "Javni ključ RSA",
    "Public key" : "Javni ključ",
    "Amazon S3" : "Amazon S3",
    "Bucket" : "Pomnilniško vedro",
    "Hostname" : "Ime gostitelja",
    "Port" : "Vrata",
    "Region" : "Območje",
    "Enable SSL" : "Omogoči SSL",
    "Enable Path Style" : "Omogoči slog poti",
    "WebDAV" : "WebDAV",
    "URL" : "Naslov URL",
    "Remote subfolder" : "Oddaljena podrejena mapa",
    "Secure https://" : "Varni način https://",
    "Dropbox" : "Dropbox",
    "FTP" : "FTP",
    "Host" : "Gostitelj",
    "Secure ftps://" : "Varni način ftps://",
    "Google Drive" : "Google Drive",
    "Local" : "Krajevno",
    "Location" : "Mesto",
    "ownCloud" : "ownCloud",
    "SFTP" : "SFTP",
    "Root" : "Koren",
    "SFTP with secret key login" : "Prijava prek protokola SFTP z geslom",
    "SMB / CIFS" : "SMB / CIFS",
    "Share" : "Souporaba",
    "Domain" : "Domena",
    "SMB / CIFS using OC login" : "SMB / CIFS z uporabo prijave OC",
    "Username as share" : "Uporabniško ime za souporabo",
    "OpenStack Object Storage" : "Shramba predmeta OpenStack",
    "Service name" : "Ime storitve",
    "<b>Note:</b> " : "<b>Opomba:</b> ",
    "<b>Note:</b> The cURL support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "<b>Opomba:</b> Podpora za naslove cURL v PHP ni omogočena, ali pa ni ustrezno nameščenih programov. Priklapljanje %s ni mogoče. Za pomoč pri namestitvi se obrnite na sistemskega skrbnika.",
    "<b>Note:</b> The FTP support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "<b>Opomba:</b> Podpora za protokol FTP v PHP ni omogočena, ali pa ni ustrezno nameščenih programov. Priklapljanje %s ni mogoče. Za pomoč pri namestitvi se obrnite na sistemskega skrbnika.",
    "<b>Note:</b> \"%s\" is not installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "<b>Opomba:</b> Program \"%s\" ni nameščen. Priklapljanje %s ni mogoče. Za pomoč pri namestitvi se obrnite na sistemskega skrbnika.",
    "No external storage configured" : "Ni določene zunanje shrambe",
    "You can add external storages in the personal settings" : "Med nastavitvami je mogoče dodati tudi zunanjo shrambo.",
    "Name" : "Ime",
    "Storage type" : "Vrsta shrambe",
    "Scope" : "Obseg",
    "External Storage" : "Zunanja podatkovna shramba",
    "Folder name" : "Ime mape",
    "Authentication" : "Overitev",
    "Configuration" : "Nastavitve",
    "Available for" : "Na voljo za",
    "Add storage" : "Dodaj shrambo",
    "Advanced settings" : "Napredne nastavitve",
    "Delete" : "Izbriši",
    "Allow users to mount external storage" : "Dovoli uporabnikom priklapljanje zunanje shrambe",
    "Allow users to mount the following external storage" : "Dovoli uporabnikom priklapljanje navedenih zunanjih shramb."
},
"nplurals=4; plural=(n%100==1 ? 0 : n%100==2 ? 1 : n%100==3 || n%100==4 ? 2 : 3);");
